@@ -122,7 +122,12 @@ SELECT * FROM check_test(
     false,
     'lives_ok failure diagnostics',
     '',
-    '        died: P0001: todo_end() called without todo_start()'
+    '    died: P0001: todo_end() called without todo_start()'
+    || CASE WHEN pg_version_num() < 90200 THEN '' ELSE '
+        CONTEXT:
+            SQL statement "SELECT * FROM todo_end()"
+            PL/pgSQL function lives_ok(text,text) line 14 at EXECUTE'
+    || CASE WHEN pg_version_num() >= 90500 THEN '' ELSE ' statement' END END
 );
 
 /****************************************************************************/
